@@ -191,7 +191,7 @@ add_esource (const gchar *conf_key,
 	const gchar *use_ssl;
 	const gchar *poa_address;
 	const gchar *group_name;
-	guint16 soap_port;
+	gchar *soap_port;
 	gboolean stay_synchronized;
 	gchar *port_string;
 
@@ -237,7 +237,7 @@ add_esource (const gchar *conf_key,
 	if (!can_create)
 		e_source_group_set_property (group, "create_source", "no");
 
-	port_string = g_strdup_printf ("%u", soap_port);
+	port_string = g_strdup(soap_port);
 
 	relative_uri = g_strdup_printf ("%s@%s/", url->user, poa_address);
 	source = e_source_new (source_name, relative_uri);
@@ -392,7 +392,7 @@ modify_esource (const gchar *conf_key,
 	const gchar *new_poa_address;
 	const gchar *new_group_name = a->name;
 	const gchar *use_ssl;
-	guint16 soap_port;
+	gchar *soap_port;
 	gboolean stay_synchronized;
 	gchar *port_string;
 
@@ -435,7 +435,7 @@ modify_esource (const gchar *conf_key,
 			g_return_if_reached ();
 	}
 
-	port_string = g_strdup_printf ("%u", soap_port);
+	port_string = g_strdup(soap_port);
 
 	for (; groups != NULL &&  !found_group; groups = g_slist_next (groups)) {
 		ESourceGroup *group = E_SOURCE_GROUP (groups->data);
@@ -552,7 +552,7 @@ get_addressbook_names_from_server (gchar *source_url)
 	guint32 flags = E_PASSWORDS_REMEMBER_FOREVER | E_PASSWORDS_SECRET;
 	CamelNetworkSecurityMethod security_method;
 	const gchar *scheme;
-	guint16 soap_port;
+	gchar *soap_port;
 
 	url = camel_url_new (source_url, NULL);
 	if (url == NULL) {
@@ -580,7 +580,7 @@ get_addressbook_names_from_server (gchar *source_url)
 
 	key = g_strdup_printf ("groupwise://%s@%s/", url->user, poa_address);
 
-	uri = g_strdup_printf ("%s://%s:%u/soap", scheme, poa_address, soap_port);
+	uri = g_strdup_printf ("%s://%s:%s/soap", scheme, poa_address, soap_port);
 
 	cnc = NULL;
 
@@ -676,7 +676,7 @@ add_addressbook_sources (EAccount *account)
 	CamelNetworkSecurityMethod security_method;
 	gboolean stay_synchronized;
 	gchar *port_string;
-	guint16 soap_port;
+	gchar *soap_port;
 
 	url = camel_url_new (account->source->url, NULL);
 	if (url == NULL) {
@@ -722,7 +722,7 @@ add_addressbook_sources (EAccount *account)
 	if (!temp_list)
 		return FALSE;
 
-	port_string = g_strdup_printf ("%u", soap_port);
+	port_string = g_strdup(soap_port);
 
 	for (; temp_list != NULL; temp_list = g_list_next (temp_list)) {
 		const gchar *book_name =  e_gw_container_get_name (E_GW_CONTAINER (temp_list->data));
@@ -746,7 +746,7 @@ add_addressbook_sources (EAccount *account)
 		e_source_set_property (source, "auth", "plain/password");
 		e_source_set_property (source, "auth-domain", "Groupwise");
 		e_source_set_property (source, "port", port_string);
-		e_source_set_property(source, "user", url->user);
+		e_source_set_property(source, "username", url->user);
 		/* mark system address book for offline usage */
 		/* FIXME: add isPersonal flag to container and use that isFrequentContact
 		 * properties, instead of using writable to distinguish between the
@@ -804,7 +804,7 @@ modify_addressbook_sources (EAccount *account,
 	const gchar *poa_address;
 	CamelNetworkSecurityMethod security_method;
 	gchar *port_string;
-	guint16 soap_port;
+	gchar *soap_port;
 
 	url = camel_url_new (existing_account_info->source_url, NULL);
 	if (url == NULL) {
@@ -850,7 +850,7 @@ modify_addressbook_sources (EAccount *account,
 			g_return_if_reached ();
 	}
 
-	port_string = g_strdup_printf ("%u", soap_port);
+	port_string = g_strdup(soap_port);
 
 	new_base_uri = g_strdup_printf ("groupwise://%s@%s", url->user, poa_address);
 
@@ -873,6 +873,7 @@ modify_addressbook_sources (EAccount *account,
 				for (; sources != NULL; sources = g_slist_next (sources)) {
 					source = E_SOURCE (sources->data);
 					e_source_set_property (source, "port", port_string);
+					e_source_set_property (source, "username", url->user);
 					e_source_set_property (source, "use_ssl", use_ssl);
 				}
 
@@ -1034,8 +1035,8 @@ account_changed (EAccountList *account_listener,
 		CamelSettings *settings;
 		CamelNetworkSecurityMethod old_security_method;
 		CamelNetworkSecurityMethod new_security_method;
-		guint16 old_soap_port;
-		guint16 new_soap_port;
+		gchar *old_soap_port;
+		gchar *new_soap_port;
 
 		if (!account->enabled) {
 			account_removed (account_listener, account);
@@ -1075,7 +1076,7 @@ account_changed (EAccountList *account_listener,
 		g_object_unref (settings);
 
 		if ((old_poa_address && strcmp (old_poa_address, new_poa_address))
-		   || old_soap_port != new_soap_port
+		   || strcmp(old_soap_port, new_soap_port)
 		   || strcmp (old_url->user, new_url->user)
 		   || old_security_method != new_security_method) {
 
